@@ -1,8 +1,5 @@
-import typing
 from typing import Union, Tuple, List, Sequence, MutableSequence
 
-T = typing.TypeVar["T"]
-
 
 def is_attrs_class(cls):
     return getattr(cls, "__attrs_attrs__", None) is not None
